pub struct Catalog { /* private fields */ }Expand description
Logical catalog: a set of TableSchemas keyed by name.
Implementations
Sourceimpl Catalog
impl Catalog
Sourcepub fn new(tables: impl IntoIterator<Item = TableSchema>) -> Self
pub fn new(tables: impl IntoIterator<Item = TableSchema>) -> Self
Builds a catalog from an iterator of table schemas.
Sourcepub fn table(&self, name: &str) -> Option<&TableSchema>
pub fn table(&self, name: &str) -> Option<&TableSchema>
Looks up a table by name; None if absent.
Sourcepub fn require_table(&self, name: &str) -> Result<&TableSchema, SqlError>
pub fn require_table(&self, name: &str) -> Result<&TableSchema, SqlError>
Looks up a table by name, returning SqlError::UnknownTable
if absent.
Errors
SqlError::UnknownTable when the table is not in the catalog.
Sourcepub fn tables(&self) -> impl Iterator<Item = &TableSchema>
pub fn tables(&self) -> impl Iterator<Item = &TableSchema>
Iterates over table schemas in stable (alphabetical) order.